@@ -9,6 +9,8 @@ from trytond.pool import Pool
 from webshop import WebShop, BannerCategory, Banner, Article
 from product import Product
 from invoice import Invoice
+from party import Address
+from shipment import ShipmentOut
 
 
 def register():
@@ -19,5 +21,7 @@ def register():
         Article,
         Product,
         Invoice,
+        Address,
+        ShipmentOut,
         module='nereid_webshop', type_='model'
     )
