@@ -22,6 +22,15 @@ class Product:
         "Returns default product image"
         ModelData = Pool().get('ir.model.data')
 
+        # Get default image from default_image_set of product template
+        # or product variant.
+        if self.use_template_images:
+            if self.template.default_image_set:
+                return self.template.default_image_set.image.id
+        elif self.default_image_set:
+            return self.default_image_set.image.id
+
+        # Fallback condition if there is no default_image_set defined
         images = self.get_images()
         if images:
             return images[0].id
