@@ -12,6 +12,7 @@ import unittest
 import trytond.tests.test_tryton
 
 from tests.test_views_depends import TestViewsDepends
+from tests.test_invoice import TestDownloadInvoice
 
 
 def suite():
@@ -21,6 +22,7 @@ def suite():
     test_suite = trytond.tests.test_tryton.suite()
     test_suite.addTests([
         unittest.TestLoader().loadTestsFromTestCase(TestViewsDepends),
+        unittest.TestLoader().loadTestsFromTestCase(TestDownloadInvoice),
     ])
     return test_suite
 
